#############################################################################
# File		: Config.py
# Package	: rpmlint
# Author	: Frederic Lepied
# Created on	: Fri Oct 15 20:04:25 1999
# Version	: $Id: Config.py,v 1.105 2004/02/12 16:36:57 flepied Exp $
# Purpose	: handle configuration options. To be used from config files.
#############################################################################

import os.path
import re
from setuplist import *

DEFAULT_CHECKS=("DistributionCheck",
		"TagsCheck",
		"BinariesCheck",
		"ConfigCheck",
		"FilesCheck",
		"FHSCheck",
		"SignatureCheck",
		"I18NCheck",
                "MenuCheck",
                "PostCheck",
                "InitScriptCheck",
		"SourceCheck",
                "SpecCheck",
                "ZipCheck",
                )

info=0
no_exception=0

# handle the list of checks to load
_checks=[]

def addCheck(check):
    global _checks
    
    if not check in _checks:
	_checks.append(check)

def allChecks():
    global _checks
    
    if _checks == []:
	_checks=DEFAULT_CHECKS
    return _checks

def defaultChecks():
    global _checks

    _checks=DEFAULT_CHECKS
    
def resetChecks():
    global _checks

    _checks=[]
    
# handle the list of directories to look for checks

_dirs=["/usr/share/rpmlint"]

def addCheckDir(dir):
    global _dirs

    dir=os.path.expanduser(dir)
    
    if not dir in _dirs:
	_dirs.insert(0, dir)

def checkDirs():
    global _dirs

    return _dirs

# handle options

_options={}

def setOption(name, value):
    global _options

    _options[name]=value

def getOption(name, default):
    global _options
    
    try:
	return _options[name]
    except:
	return default

# List of filters
_filters=[]
_filters_re=None

def addFilter(s):
    global _filters
    global _filters_re

    _filters.append(s)
    _filters_re=None
    
def isFiltered(s):
    global _filters
    global _filters_re

    if _filters_re == None:
        # no filter
        if len(_filters) == 0:
            return 0
        _filters_re = '(?:' + _filters[0] + ')'
        
        for idx in range(1, len(_filters)):
            _filters_re = _filters_re + '|(?:' + _filters[idx] +')'
        _filters_re = re.compile(_filters_re)
        
    if not no_exception:
        if _filters_re.search(s):
            return 1
    return 0
    

################################################################################
# policy decisions. The idea is to be able to run rpmlint as an old version.
################################################################################

DEFAULT_LAUNCHERS_OLD = (['(?:/usr/bin/)?kdesu', ('/usr/bin/kdesu', 'kdesu')],
                         ['(?:/usr/bin/)?launch_x11_clanapp', ('/usr/bin/launch_x11_clanapp', 'clanlib', 'libclanlib0')],
                         ['(?:/usr/bin/)?soundwrapper', None],
                         ['NO_XALF', None],
                         )
DEFAULT_LAUNCHERS_90 = (['(?:/usr/bin/)?kdesu', ('/usr/bin/kdesu', 'kdesu')],
                        ['(?:/usr/bin/)?launch_x11_clanapp', ('/usr/bin/launch_x11_clanapp', 'clanlib', 'libclanlib0')],
                        ['(?:/usr/bin/)?soundwrapper', None],
                        )

DEFAULT_LAUNCHERS = DEFAULT_LAUNCHERS_90

STANDARD_GROUPS = STANDARD_GROUPS_NEW
STANDARD_USERS = STANDARD_USERS_NEW

def load_policy(policy):
    if policy != 'mdk9.2':
        addFilter('no-epoch-tag|unreasonable-epoch|no-epoch-in-obsoletes|no-epoch-in-conflicts|no-epoch-in-provides|no-epoch-in-dependency|devel-dependency|invalid-build-requires')
        if policy != 'mdk9.1':
            addFilter('lib-package-without-%mklibname|outside-libdir-files')
            if policy != 'mdk9.0':
                addFilter('no-prereq-on|non-root-user-log-file|non-root-group-log-file|non-ghost-file|hardcoded-library-path|configure-without-libdir-spec|no-binary|only-non-binary-in-usr-lib')
                DEFAULT_LAUNCHERS = DEFAULT_LAUNCHERS_OLD
                STANDARD_GROUPS = STANDARD_GROUPS_OLD
                STANDARD_USERS = STANDARD_USERS_OLD
        
# Config.py ends here
